# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WatticsSite(Model):
    """WatticsSite.

    :param wattics_site_id: The identifier for a Wattics site
    :type wattics_site_id: int
    """

    _attribute_map = {
        'wattics_site_id': {'key': 'watticsSiteId', 'type': 'int'},
    }

    def __init__(self, *, wattics_site_id: int=None, **kwargs) -> None:
        super(WatticsSite, self).__init__(**kwargs)
        self.wattics_site_id = wattics_site_id
