# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PeriodComparison(Model):
    """General purpose period comparison DTO.

    :param current_period: The date for the current period of data
    :type current_period: int
    :param previous_period: The date for the previous period of data
    :type previous_period: int
    :param current_value:
    :type current_value: ~energycap.sdk.models.ValueWithUnit
    :param previous_value:
    :type previous_value: ~energycap.sdk.models.ValueWithUnit
    """

    _attribute_map = {
        'current_period': {'key': 'currentPeriod', 'type': 'int'},
        'previous_period': {'key': 'previousPeriod', 'type': 'int'},
        'current_value': {'key': 'currentValue', 'type': 'ValueWithUnit'},
        'previous_value': {'key': 'previousValue', 'type': 'ValueWithUnit'},
    }

    def __init__(self, **kwargs):
        super(PeriodComparison, self).__init__(**kwargs)
        self.current_period = kwargs.get('current_period', None)
        self.previous_period = kwargs.get('previous_period', None)
        self.current_value = kwargs.get('current_value', None)
        self.previous_value = kwargs.get('previous_value', None)
